@@ -1,6 +1,6 @@
 test_that("acro_crosstab without initialising ACRO object first", {
   acroEnv$ac <- NULL
-  expect_error(acro_crosstab(index=nursery_data[, c("health")], columns = nursery_data[, c("finance")]), "ACRO has not been initialised. Please first call acro_init()")
+  expect_error(acro_crosstab(index = nursery_data[, c("health")], columns = nursery_data[, c("finance")]), "ACRO has not been initialised. Please first call acro_init()")
 })
 
 test_that("acro_crosstab works", {
@@ -15,6 +15,6 @@ test_that("acro_crosstab works", {
   row.names(expected_table) <- c("not_recom", "priority", "recommended")
 
   acro_init()
-  table = acro_crosstab(index=nursery_data[, c("health")], columns = nursery_data[, c("finance")])
+  table <- acro_crosstab(index = nursery_data[, c("health")], columns = nursery_data[, c("finance")])
   expect_equal(table[, -1, drop = FALSE], expected_table[, -1, drop = FALSE])
 })
