@@ -6,10 +6,9 @@ test_that("acro_hist without initialising ACRO object first", {
 test_that("acro_hist works", {
   testthat::skip_on_cran()
   acro_init()
-  filename = acro_hist(nursery_data, "children")
+  filename <- acro_hist(nursery_data, "children")
   expect_true(file.exists(filename))
 })
 
 # Delete the acro_artifacts folder
 unlink("acro_artifacts", recursive = TRUE)
-
